#!/bin/sh
#
#  phase1_amber.sh - run Amber on a PDB complex as:
#
#     ./phase1_amber.sh <prefix> <r1> <r2>
#
#  prefix = root file name
#
#  r1 = no. residues in the 1st (A) chain
#  r2 = no. residues in the 2nd (B) chain
#
#  This uses the MMTSB tool minAmber.pl
#
#  Dave Ritchie 24/02/07
#
# ---------------------------------------------------------------------------
#
if [ -z "$3" ]; then
   echo "usage: phase1_amber.sh <prefix>  <r1> <r2>"
   echo " "
   exit
fi

prefix=$1

let r1a=1
let r1b=$2
let r2a=$r1b+1
let r2b=$r1b+$3

tmp1=tt$$.tmp
tmp2=uu$$.tmp
tmp3=vv$$.tmp
tmp4=ww$$.tmp
tmp5=xx$$.tmp
tmp6=yy$$.tmp
tmp7=zz$$.tmp

#
#  run Amber - on output, the chains are merged into one blank chain!
#
hex_strip_hydrogens <${prefix}.pdb | hex_oxt >$tmp1

minAmber.pl -par sdsteps=100,minsteps=750 -log ${prefix}.log $tmp1 > $tmp2

# minAmber.pl -par sdsteps=10,minsteps=5 -log ${prefix}.log $tmp1 > $tmp2

#
#  reset the chain IDs
#

hex_chain ' ' A $r1a $r1b <$tmp2 | hex_chain ' ' B $r2a $r2b >$tmp3

#
#  make the B chain count from 1
#
hex_delta B -$r1b <$tmp3 >$tmp4

#
#  remove the END and TER keywords
#

cat $tmp4 | grep -v "END" | grep -v "TER" > $tmp5

#
#  remove the Amber Hydrogens and rename OT1 to O ant OT2 to OXT for Hex
#

hex_strip_hydrogens <$tmp5 | hex_oxt >$tmp6

#
#  renumber the remaining atoms consecutively
#
hex_resequence <$tmp6 > ${prefix}_amber_AB.pdb

#
#  split into two files
#
grep " A " <${prefix}_amber_AB.pdb >${prefix}_amber_A.pdb
grep " B " <${prefix}_amber_AB.pdb >${prefix}_amber_B.pdb

#
#   done
#

/bin/rm -f $tmp1 $tmp2 $tmp3 $tmp4 $tmp5 $tmp6

